@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2014-2019 Roger Light <roger@atchoo.org>
+Copyright (c) 2014-2020 Roger Light <roger@atchoo.org>
 
 All rights reserved. This program and the accompanying materials
 are made available under the terms of the Eclipse Public License v1.0
@@ -102,6 +102,7 @@ struct mosq_config {
 	char *format; /* sub */
 	int timeout; /* sub */
 	int sub_opts; /* sub */
+	long session_expiry_interval;
 #ifdef WITH_SOCKS
 	char *socks5_host;
 	int socks5_port;
@@ -126,4 +127,6 @@ int client_connect(struct mosquitto *mosq, struct mosq_config *cfg);
 
 int cfg_parse_property(struct mosq_config *cfg, int argc, char *argv[], int *idx);
 
+void err_printf(const struct mosq_config *cfg, const char *fmt, ...);
+
 #endif
