@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2009-2018 Roger Light <roger@atchoo.org>
+Copyright (c) 2009-2020 Roger Light <roger@atchoo.org>
 
 All rights reserved. This program and the accompanying materials
 are made available under the terms of the Eclipse Public License v1.0
@@ -47,7 +47,8 @@ enum rr__state {
 
 static enum rr__state client_state = rr_s_new;
 
-struct mosq_config cfg;
+extern struct mosq_config cfg;
+
 bool process_messages = true;
 int msg_count = 0;
 struct mosquitto *mosq = NULL;
