@@ -1,5 +1,5 @@
 /*
-Copyright (c) 2016-2019 Roger Light <roger@atchoo.org>
+Copyright (c) 2016-2020 Roger Light <roger@atchoo.org>
 
 All rights reserved. This program and the accompanying materials
 are made available under the terms of the Eclipse Public License v1.0
@@ -65,7 +65,14 @@ void *mosquitto_client_certificate(const struct mosquitto *client)
 
 int mosquitto_client_protocol(const struct mosquitto *client)
 {
-	return client->protocol;
+#ifdef WITH_WEBSOCKETS
+	if(client->wsi){
+		return mp_websockets;
+	}else
+#endif
+	{
+		return mp_mqtt;
+	}
 }
 
 
