@@ -22,8 +22,10 @@ try:
     sock.close()
     if len(data) == 0:
         rc = 0
-except socket.error:
-    rc = 0
+except socket.error as e:
+    if e.errno == errno.ECONNRESET:
+        # Connection has been closed by peer, this is the expected behaviour
+        rc = 0
 finally:
     broker.terminate()
     broker.wait()
