@@ -1,21 +1,13 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 # Test whether a UNSUBSCRIBE with no topic results in a disconnect. MQTT-3.10.3-2
 
-import inspect, os, sys
-import struct
+from mosq_test_helper import *
 
 def gen_unsubscribe_invalid_no_topic(mid):
     pack_format = "!BBH"
     return struct.pack(pack_format, 162, 2, mid)
 
-# From http://stackoverflow.com/questions/279237/python-import-a-module-from-a-folder
-cmd_subfolder = os.path.realpath(os.path.abspath(os.path.join(os.path.split(inspect.getfile( inspect.currentframe() ))[0],"..")))
-if cmd_subfolder not in sys.path:
-    sys.path.insert(0, cmd_subfolder)
-
-import mosq_test
-
 rc = 1
 mid = 3
 keepalive = 60
@@ -29,7 +21,7 @@ broker = mosq_test.start_broker(filename=os.path.basename(__file__), port=port)
 
 try:
     sock = mosq_test.do_client_connect(connect_packet, connack_packet, port=port)
-    mosq_test.do_send_receive(sock, unsubscribe_packet, "", "disconnect")
+    mosq_test.do_send_receive(sock, unsubscribe_packet, b"", "disconnect")
 
     rc = 0
 
@@ -39,7 +31,7 @@ finally:
     broker.wait()
     (stdo, stde) = broker.communicate()
     if rc:
-        print(stde)
+        print(stde.decode('utf-8'))
 
 exit(rc)
 
