@@ -1,18 +1,9 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 # Test whether a bridge topics work correctly after reconnection.
 # Important point here is that persistence is enabled.
 
-import subprocess
-import time
-
-import inspect, os, sys
-# From http://stackoverflow.com/questions/279237/python-import-a-module-from-a-folder
-cmd_subfolder = os.path.realpath(os.path.abspath(os.path.join(os.path.split(inspect.getfile( inspect.currentframe() ))[0],"..")))
-if cmd_subfolder not in sys.path:
-    sys.path.insert(0, cmd_subfolder)
-
-import mosq_test
+from mosq_test_helper import *
 
 def write_config(filename, port1, port2):
     with open(filename, 'w') as f:
@@ -86,15 +77,15 @@ finally:
     broker.wait()
     (stdo, stde) = broker.communicate()
     if rc:
-        print(stde)
+        print(stde.decode('utf-8'))
     local_broker.terminate()
     local_broker.wait()
     if rc:
         (stdo, stde) = local_broker.communicate()
-        print(stde)
+        print(stde.decode('utf-8'))
         if pub:
             (stdo, stde) = pub.communicate()
-            print(stdo)
+            print(stdo.decode('utf-8'))
 
     try:
         os.remove('mosquitto-%d.db' % (port1))
