@@ -1,16 +1,9 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 # Test whether a connection is disconnected if it sets the will flag but does
 # not provide a will payload.
 
-import inspect, os, sys
-# From http://stackoverflow.com/questions/279237/python-import-a-module-from-a-folder
-cmd_subfolder = os.path.realpath(os.path.abspath(os.path.join(os.path.split(inspect.getfile( inspect.currentframe() ))[0],"..")))
-if cmd_subfolder not in sys.path:
-    sys.path.insert(0, cmd_subfolder)
-
-import struct
-import mosq_test
+from mosq_test_helper import *
 
 rc = 1
 keepalive = 10
@@ -26,7 +19,7 @@ port = mosq_test.get_port()
 broker = mosq_test.start_broker(filename=os.path.basename(__file__), port=port)
 
 try:
-    sock = mosq_test.do_client_connect(connect_packet, "", port=port)
+    sock = mosq_test.do_client_connect(connect_packet, b"", port=port)
     sock.close()
     rc = 0
 finally:
@@ -34,7 +27,7 @@ finally:
     broker.wait()
     (stdo, stde) = broker.communicate()
     if rc:
-        print(stde)
+        print(stde.decode('utf-8'))
 
 exit(rc)
 
