@@ -16,6 +16,10 @@ try:
     sock = mosq_test.do_client_connect(connect_packet, b"", timeout=30, port=port)
     rc = 0
     sock.close()
+except socket.error as e:
+    if e.errno == errno.ECONNRESET:
+        # Connection has been closed by peer, this is the expected behaviour
+        rc = 0
 finally:
     broker.terminate()
     broker.wait()
