@@ -1,23 +1,11 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
-import subprocess
-import ssl
-import sys
-import time
+from mosq_test_helper import *
 
 if sys.version < '2.7':
     print("WARNING: SSL not supported on Python 2.6")
     exit(0)
 
-
-import inspect, os
-# From http://stackoverflow.com/questions/279237/python-import-a-module-from-a-folder
-cmd_subfolder = os.path.realpath(os.path.abspath(os.path.join(os.path.split(inspect.getfile( inspect.currentframe() ))[0],"..")))
-if cmd_subfolder not in sys.path:
-    sys.path.insert(0, cmd_subfolder)
-
-import mosq_test
-
 def write_config1(filename, port1, port2):
     with open(filename, 'w') as f:
         f.write("allow_anonymous true\n")
@@ -95,12 +83,12 @@ finally:
     bridge.wait()
     (stdo, stde) = broker.communicate()
     if rc:
-        print(stde)
+        print(stde.decode('utf-8'))
         (stdo, stde) = bridge.communicate()
-        print(stde)
+        print(stde.decode('utf-8'))
         if pub:
             (stdo, stde) = pub.communicate()
-            print(stdo)
+            print(stdo.decode('utf-8'))
 
 exit(rc)
 
