@@ -1,14 +1,8 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 # Test whether a client subscribed to a topic receives its own message sent to that topic.
 
-import inspect, os, sys
-# From http://stackoverflow.com/questions/279237/python-import-a-module-from-a-folder
-cmd_subfolder = os.path.realpath(os.path.abspath(os.path.join(os.path.split(inspect.getfile( inspect.currentframe() ))[0],"..")))
-if cmd_subfolder not in sys.path:
-    sys.path.insert(0, cmd_subfolder)
-
-import mosq_test
+from mosq_test_helper import *
 
 def write_config(filename, port):
     with open(filename, 'w') as f:
@@ -24,10 +18,10 @@ rc = 1
 mid = 530
 keepalive = 60
 connect_packet = mosq_test.gen_connect(
-    "persitent-subscription-test", keepalive=keepalive, clean_session=False,
+    "persistent-subscription-test", keepalive=keepalive, clean_session=False,
 )
 connack_packet = mosq_test.gen_connack(rc=0)
-connack_packet2 = mosq_test.gen_connack(rc=0, resv=1)  # session present
+connack_packet2 = mosq_test.gen_connack(rc=0, flags=1)  # session present
 
 subscribe_packet = mosq_test.gen_subscribe(mid, "subpub/qos1", 1)
 suback_packet = mosq_test.gen_suback(mid, 1)
@@ -69,7 +63,7 @@ finally:
     broker.wait()
     (stdo, stde) = broker.communicate()
     if rc:
-        print(stde1 + stde)
+        print(stde.decode('utf-8'))
     if os.path.exists('mosquitto-%d.db' % (port)):
         os.unlink('mosquitto-%d.db' % (port))
 
