@@ -19,9 +19,6 @@ suback_packet = mosq_test.gen_suback(mid, 0, proto_ver=5)
 publish1_packet = mosq_test.gen_publish(topic="test/topic", qos=0, payload="12345678901234567890", proto_ver=5)
 publish2_packet = mosq_test.gen_publish(topic="test/topic", qos=0, payload="67890", proto_ver=5)
 
-pingreq_packet = mosq_test.gen_pingreq()
-pingresp_packet = mosq_test.gen_pingresp()
-
 port = mosq_test.get_port()
 broker = mosq_test.start_broker(filename=os.path.basename(__file__), port=port)
 
@@ -30,9 +27,9 @@ try:
     mosq_test.do_send_receive(sock, subscribe_packet, suback_packet)
     sock.send(publish1_packet)
     # We shouldn't receive the publish here because it is > MAXIMUM_PACKET_SIZE
-    mosq_test.do_send_receive(sock, pingreq_packet, pingresp_packet)
+    mosq_test.do_ping(sock, "pingresp1")
     mosq_test.do_send_receive(sock, publish2_packet, publish2_packet)
-    mosq_test.do_send_receive(sock, pingreq_packet, pingresp_packet)
+    mosq_test.do_ping(sock, "pingresp2")
     rc = 0
 finally:
     broker.terminate()
