@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 # Test whether a client produces a correct connect with a will, username and password.
 
@@ -7,17 +7,7 @@
 # set to "will message", will qos=2, will retain not set, username set to
 # "oibvvwqw" and password set to "#'^2hg9a&nm38*us".
 
-import inspect
-import os
-import socket
-import sys
-
-# From http://stackoverflow.com/questions/279237/python-import-a-module-from-a-folder
-cmd_subfolder = os.path.realpath(os.path.abspath(os.path.join(os.path.split(inspect.getfile( inspect.currentframe() ))[0],"..")))
-if cmd_subfolder not in sys.path:
-    sys.path.insert(0, cmd_subfolder)
-
-import mosq_test
+from mosq_test_helper import *
 
 port = mosq_test.get_lib_port()
 
@@ -25,7 +15,7 @@ rc = 1
 keepalive = 60
 connect_packet = mosq_test.gen_connect("01-will-unpwd-set",
         keepalive=keepalive, username="oibvvwqw", password="#'^2hg9a&nm38*us",
-        will_topic="will-topic", will_qos=2, will_payload="will message")
+        will_topic="will-topic", will_qos=2, will_payload=b"will message")
 
 sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
 sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
