@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 # Test whether a client sends a correct PUBLISH to a topic with QoS 1 and responds to a delay.
 
@@ -16,17 +16,7 @@
 # PUBACK response. On receiving the correct PUBACK response, the client should
 # send a DISCONNECT message.
 
-import inspect
-import os
-import socket
-import sys
-
-# From http://stackoverflow.com/questions/279237/python-import-a-module-from-a-folder
-cmd_subfolder = os.path.realpath(os.path.abspath(os.path.join(os.path.split(inspect.getfile( inspect.currentframe() ))[0],"..")))
-if cmd_subfolder not in sys.path:
-    sys.path.insert(0, cmd_subfolder)
-
-import mosq_test
+from mosq_test_helper import *
 
 port = mosq_test.get_lib_port()
 
