@@ -17,12 +17,14 @@ int main(int argc, char *argv[])
 {
 	struct mosquittopp_test *mosq;
 
+	int port = atoi(argv[1]);
+
 	mosqpp::lib_init();
 
 	mosq = new mosquittopp_test("01-unpwd-set");
 	mosq->username_pw_set("uname", ";'[08gn=#");
 
-	mosq->connect("localhost", 1888, 60);
+	mosq->connect("localhost", port, 60);
 
 	while(run == -1){
 		mosq->loop();
