@@ -17,13 +17,15 @@ int main(int argc, char *argv[])
 {
 	struct mosquittopp_test *mosq;
 
+	int port = atoi(argv[1]);
+
 	mosqpp::lib_init();
 
 	mosq = new mosquittopp_test("01-will-unpwd-set");
 	mosq->username_pw_set("oibvvwqw", "#'^2hg9a&nm38*us");
 	mosq->will_set("will-topic", strlen("will message"), "will message", 2, false);
 
-	mosq->connect("localhost", 1888, 60);
+	mosq->connect("localhost", port, 60);
 
 	while(run == -1){
 		mosq->loop();
