@@ -34,6 +34,8 @@ int main(int argc, char *argv[])
 {
 	struct mosquittopp_test *mosq;
 
+	int port = atoi(argv[1]);
+
 	mosqpp::lib_init();
 
 	mosq = new mosquittopp_test("08-ssl-connect-no-auth");
@@ -41,7 +43,7 @@ int main(int argc, char *argv[])
 	mosq->tls_opts_set(1, "tlsv1", NULL);
 	//mosq->tls_set("../ssl/test-root-ca.crt");
 	mosq->tls_set("../ssl/all-ca.crt");
-	mosq->connect("localhost", 1888, 60);
+	mosq->connect("localhost", port, 60);
 
 	while(run == -1){
 		mosq->loop();
