@@ -25,13 +25,15 @@ int main(int argc, char *argv[])
 	struct mosquittopp_test *mosq;
 	int rc;
 
+	int port = atoi(argv[1]);
+
 	mosqpp::lib_init();
 
 	mosq = new mosquittopp_test("08-ssl-fake-cacert");
 
 	mosq->tls_opts_set(1, "tlsv1", NULL);
 	mosq->tls_set("../ssl/test-fake-root-ca.crt", NULL, "../ssl/client.crt", "../ssl/client.key");
-	mosq->connect("localhost", 1888, 60);
+	mosq->connect("localhost", port, 60);
 
 	rc = mosq->loop_forever();
 	if(rc == MOSQ_ERR_ERRNO && errno == EPROTO){
